/***********************************************************
 * $Id: fancyqmiasynchandler.h 1601 2015-03-13 08:32:22Z fancylibs $
 *
 * FancyLibs qmi wrapper
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYQMIASYNCHANDLER_H_
#define FANCYQMIASYNCHANDLER_H_

#include <fancyqmi.h>
#include <fancyobject.h>

#include <exception>

namespace Fancy {
namespace QMI {

/**
 * A handler for receiving results of asynchronous results.
 */
class FANCYQMI_API QmiAsyncHandler : virtual public Fancy::Object
{
public:
	typedef Fancy::ObjPtr<QmiAsyncHandler> ptr_t;

	typedef void (*cancel_func_t)(void *);

	/**
	 * Called upon the finish of an asynchronous operation.
	 *
	 * @param operation The operation name ins the for <class>::<method>
	 *                  like DmsDevice::open
	 * @param res The result of the operation to be casted to the intended
	 *            return as documented by the invoked operation.
	 */
	virtual void onResultReady(const std::string &operation, const Fancy::ObjPtr<Fancy::Object> &res) = 0;

	/**
	 * Called upon the finish of an asynchronous operation.
	 *
	 * @param operation The operation name ins the for <class>::<method>
	 *                  like DmsDevice::open
	 * @param e The exception thrown by the invoked operation.
	 */
	virtual void onException(const std::string &operation, std::exception &e) = 0;

	/**
	 * Cancel the running operation for which this handler
	 * is currently registered.
	 */
	void cancel();

	/**
	 * Initialize the cancel callback, this is called internally by the
	 * library. It is an error to call this function twice with non-null
	 * pointer. If the library resets the pointer to null after the finish
	 * of an asynchronous function, this function may be used again, so
	 * an QmAsyncHandler instance may be reused after the finish of
	 * an asynchronous operation it is registered for.
	 */
	void initCancel(cancel_func_t cf, void *cd);

protected:

	QmiAsyncHandler();
	virtual ~QmiAsyncHandler();

private:
	cancel_func_t cancel_func;
	void *cancel_data;
};

}} // end namespaces

#endif
