/***********************************************************
 * $Id: fancyqmienums.h 1617 2015-03-17 13:09:03Z fancylibs $
 *
 * FancyLibs qmi wrapper
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYQMIENUMS_H_
#define FANCYQMIENUMS_H_

#include <fancyqmi.h>
#include <iosfwd>

namespace Fancy {
namespace QMI {

enum OperatingMode {
    OperatingModeOnline                = 0,
	OperatingModeLowPower              = 1,
	OperatingModeFactoryTest           = 2,
	OperatingModeOffline               = 3,
	OperatingModeReset                 = 4,
	OperatingModeShuttingDown          = 5,
	OperatingModePersistentLowPower    = 6,
	OperatingModeOnlyLowPower          = 7
};

const char* FANCYQMI_API formatOperatingMode(OperatingMode om);

enum RadioInterface {
    RadioInterfaceUnknown     = -1,
    RadioInterfaceNone        = 0x00,
    RadioInterfaceCDMA1X      = 0x01,
    RadioInterfaceCDMA1XEVDO  = 0x02,
    RadioInterfaceAMPS        = 0x03,
    RadioInterfaceGSM         = 0x04,
    RadioInterfaceUMTS        = 0x05,
    RadioInterfaceLTE         = 0x08,
    RadioInterfaceTD_SCDMA    = 0x09
};

const char* FANCYQMI_API formatRadioInterface(RadioInterface ri);

/**
 * RadioTechnologyPreference and QmiNasClient::setNetworkPreference()
 * is deprecated, use RatModePreference mask and
 * QmiNasClient::setRatModePreferenceMask() instead
 */
enum RadioTechnologyPreference {
	RadioTechnologyPreferenceAUTO          = 0,
	RadioTechnologyPreference3GPP2         = 1 << 0,
	RadioTechnologyPreference3GPP          = 1 << 1,
	RadioTechnologyPreferenceAMPS_OR_GSM   = 1 << 2,
	RadioTechnologyPreferenceCDMA_OR_WCDMA = 1 << 3,
	RadioTechnologyPreferenceHDR           = 1 << 4,
	RadioTechnologyPreferenceLTE           = 1 << 5
};

const char * FANCYQMI_API formatRadioTechnologyPreference(RadioTechnologyPreference rtp);

enum PreferenceDuration {
	PreferenceDurationPERMANENT           = 0x00,
	PreferenceDurationPOWER_CYCLE         = 0x01,
	PreferenceDurationONE_CALL            = 0x02,
	PreferenceDurationONE_CALL_OR_TIME    = 0x03,
	PreferenceDurationINTERNAL_ONE_CALL_1 = 0x04,
	PreferenceDurationINTERNAL_ONE_CALL_2 = 0x05,
	PreferenceDurationINTERNAL_ONE_CALL_3 = 0x06
};

const char * FANCYQMI_API formatPreferenceDuration(PreferenceDuration pd);

enum RatModePreference {
	RatModePreference_CDMA_1X     = 1 << 0,
	RatModePreference_CDMA_1XEVDO = 1 << 1,
	RatModePreference_GSM         = 1 << 2,
	RatModePreference_UMTS        = 1 << 3,
	RatModePreference_LTE         = 1 << 4,
	RatModePreference_TD_SCDMA    = 1 << 5
};

std::string FANCYQMI_API formatRatModePreferenceMask(int ratModePreferenceMask);

enum NetworkServiceDomain {
	NetworkServiceDomain_NONE    = 0x00,
	/**
	 * circuit switched
	 */
	NetworkServiceDomain_CS      = 0x01,
	/**
	 * packet switched
	 */
	NetworkServiceDomain_PS      = 0x02,
	/**
	 * packet and circuit switched
	 */
	NetworkServiceDomain_CS_PS   = 0x03,
	NetworkServiceDomain_UNKNOWN = 0x04,
};

const char *FANCYQMI_API formatNetworkServiceDomain(NetworkServiceDomain nsd);

enum RoamingStatus{
    RoamingStatus_OFF                 = 0x00,
    RoamingStatus_ON                  = 0x01,
    /* Next ones only for 3GPP2 */
    RoamingStatus_BLINK               = 0x02,
    RoamingStatus_OUT_OF_NEIGHBORHOOD = 0x03,
    RoamingStatus_OUT_OF_BUILDING     = 0x04,
    RoamingStatus_PREFERRED_SYSTEM    = 0x05,
    RoamingStatus_AVAILABLE_SYSTEM    = 0x06,
    RoamingStatus_ALLIANCE_PARTNER    = 0x07,
    RoamingStatus_PREMIUM_PARTNER     = 0x08,
    RoamingStatus_FULL_SERVICE        = 0x09,
    RoamingStatus_PARTIAL_SERVICE     = 0x0A,
    RoamingStatus_BANNER_ON           = 0x0B,
    RoamingStatus_BANNER_OFF          = 0x0C
};

const char * FANCYQMI_API formatRoamingStatus(RoamingStatus rs);

}} // end namespaces

#endif
