/***********************************************************
 * $Id: fancyqmisysteminfo.h 1610 2015-03-16 16:38:32Z fancylibs $
 *
 * FancyLibs qmi wrapper
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYQMISYSTEMINFO_H_
#define FANCYQMISYSTEMINFO_H_

#include <fancyqmienums.h>
#include <fancynumbers.h>
#include <fancystring.h>

namespace Fancy {

class String;

namespace QMI {

/**
 * A detailed signal information reported to listeners.
 */
class FANCYQMI_API QmiSystemInfo : virtual public Fancy::Object
{
public:
	typedef Fancy::ObjPtr<QmiSystemInfo> ptr_t;

	static ptr_t newInstance();



	std::string toString() const;

	const Fancy::ObjPtr<Fancy::Integer>& getCid() const {
		return cid;
	}

	void setCid(const Fancy::ObjPtr<Fancy::Integer>& cid) {
		this->cid = cid;
	}

	const Fancy::ObjPtr<Fancy::Integer>& getLac() const {
		return lac;
	}

	void setLac(const Fancy::ObjPtr<Fancy::Integer>& lac) {
		this->lac = lac;
	}

	const Fancy::ObjPtr<Fancy::String>& getMcc() const {
		return mcc;
	}

	void setMcc(const Fancy::ObjPtr<Fancy::String>& mcc) {
		this->mcc = mcc;
	}

	const Fancy::ObjPtr<Fancy::String>& getMnc() const {
		return mnc;
	}

	void setMnc(const Fancy::ObjPtr<Fancy::String>& mnc) {
		this->mnc = mnc;
	}

	RadioInterface getRadioInterface() const {
		return radioInterface;
	}

	void setRadioInterface(RadioInterface radioInterface) {
		this->radioInterface = radioInterface;
	}

	RoamingStatus getRoamingStatus() const {
		return roamingStatus;
	}

	void setRoamingStatus(RoamingStatus roamingStatus) {
		this->roamingStatus = roamingStatus;
	}

	NetworkServiceDomain getServiceCapabilities() const {
		return serviceCapabilities;
	}

	void setServiceCapabilities(NetworkServiceDomain serviceCapabilities) {
		this->serviceCapabilities = serviceCapabilities;
	}

	NetworkServiceDomain getServiceDomain() const {
		return serviceDomain;
	}

	void setServiceDomain(NetworkServiceDomain serviceDomain) {
		this->serviceDomain = serviceDomain;
	}

	const Fancy::ObjPtr<Fancy::Boolean>& getForbidden() const {
		return forbidden;
	}

	void setForbidden(const Fancy::ObjPtr<Fancy::Boolean>& forbidden) {
		this->forbidden = forbidden;
	}

protected:

	RadioInterface radioInterface;
	NetworkServiceDomain serviceDomain;
	NetworkServiceDomain serviceCapabilities;
	RoamingStatus roamingStatus;
	Fancy::ObjPtr<Fancy::Boolean> forbidden;
	Fancy::ObjPtr<Fancy::Integer> lac;
	Fancy::ObjPtr<Fancy::Integer> cid;
	Fancy::ObjPtr<Fancy::String> mnc;
	Fancy::ObjPtr<Fancy::String> mcc;

	QmiSystemInfo();
	virtual ~QmiSystemInfo();

private:
};

}} // end namespaces

#endif
